==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTRuleFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface JWTRuleFluent<A extends JWTRuleFluent<A>> extends Fluent<A>{
  public A addToAudiences(Integer index,String item);
  public A setToAudiences(Integer index,String item);
  public A addToAudiences(java.lang.String... items);
  public A addAllToAudiences(Collection<String> items);
  public A removeFromAudiences(java.lang.String... items);
  public A removeAllFromAudiences(Collection<String> items);
  public List<String> getAudiences();
  public String getAudience(Integer index);
  public String getFirstAudience();
  public String getLastAudience();
  public String getMatchingAudience(Predicate<String> predicate);
  public Boolean hasMatchingAudience(Predicate<String> predicate);
  public A withAudiences(List<String> audiences);
  public A withAudiences(java.lang.String... audiences);
  public Boolean hasAudiences();
  public Boolean getForwardOriginalToken();
  public A withForwardOriginalToken(Boolean forwardOriginalToken);
  public Boolean hasForwardOriginalToken();
  public A addToFromHeaders(Integer index,JWTHeader item);
  public A setToFromHeaders(Integer index,JWTHeader item);
  public A addToFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... items);
  public A addAllToFromHeaders(Collection<JWTHeader> items);
  public A removeFromFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... items);
  public A removeAllFromFromHeaders(Collection<JWTHeader> items);
  public A removeMatchingFromFromHeaders(Predicate<JWTHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFromHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<JWTHeader> getFromHeaders();
  public List<JWTHeader> buildFromHeaders();
  public JWTHeader buildFromHeader(Integer index);
  public JWTHeader buildFirstFromHeader();
  public JWTHeader buildLastFromHeader();
  public JWTHeader buildMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public Boolean hasMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public A withFromHeaders(List<JWTHeader> fromHeaders);
  public A withFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... fromHeaders);
  public Boolean hasFromHeaders();
  public A addNewFromHeader(String name,String prefix);
  public JWTRuleFluent.FromHeadersNested<A> addNewFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> addNewFromHeaderLike(JWTHeader item);
  public JWTRuleFluent.FromHeadersNested<A> setNewFromHeaderLike(Integer index,JWTHeader item);
  public JWTRuleFluent.FromHeadersNested<A> editFromHeader(Integer index);
  public JWTRuleFluent.FromHeadersNested<A> editFirstFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> editLastFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> editMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public A addToFromParams(Integer index,String item);
  public A setToFromParams(Integer index,String item);
  public A addToFromParams(java.lang.String... items);
  public A addAllToFromParams(Collection<String> items);
  public A removeFromFromParams(java.lang.String... items);
  public A removeAllFromFromParams(Collection<String> items);
  public List<String> getFromParams();
  public String getFromParam(Integer index);
  public String getFirstFromParam();
  public String getLastFromParam();
  public String getMatchingFromParam(Predicate<String> predicate);
  public Boolean hasMatchingFromParam(Predicate<String> predicate);
  public A withFromParams(List<String> fromParams);
  public A withFromParams(java.lang.String... fromParams);
  public Boolean hasFromParams();
  public String getIssuer();
  public A withIssuer(String issuer);
  public Boolean hasIssuer();
  public String getJwks();
  public A withJwks(String jwks);
  public Boolean hasJwks();
  public String getJwksUri();
  public A withJwksUri(String jwksUri);
  public Boolean hasJwksUri();
  public String getOutputPayloadToHeader();
  public A withOutputPayloadToHeader(String outputPayloadToHeader);
  public Boolean hasOutputPayloadToHeader();
  public A withForwardOriginalToken();
  public interface FromHeadersNested<N> extends Nested<N>,JWTHeaderFluent<JWTRuleFluent.FromHeadersNested<N>>{
    public N and();
    public N endFromHeader();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTRuleFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface JWTRuleFluent<A extends JWTRuleFluent<A>> extends Fluent<A>{
  public A addToAudiences(int index,String item);
  public A setToAudiences(int index,String item);
  public A addToAudiences(java.lang.String... items);
  public A addAllToAudiences(Collection<String> items);
  public A removeFromAudiences(java.lang.String... items);
  public A removeAllFromAudiences(Collection<String> items);
  public List<String> getAudiences();
  public String getAudience(int index);
  public String getFirstAudience();
  public String getLastAudience();
  public String getMatchingAudience(Predicate<String> predicate);
  public Boolean hasMatchingAudience(Predicate<String> predicate);
  public A withAudiences(List<String> audiences);
  public A withAudiences(java.lang.String... audiences);
  public Boolean hasAudiences();
  public Boolean getForwardOriginalToken();
  public A withForwardOriginalToken(Boolean forwardOriginalToken);
  public Boolean hasForwardOriginalToken();
  public A addToFromHeaders(int index,JWTHeader item);
  public A setToFromHeaders(int index,JWTHeader item);
  public A addToFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... items);
  public A addAllToFromHeaders(Collection<JWTHeader> items);
  public A removeFromFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... items);
  public A removeAllFromFromHeaders(Collection<JWTHeader> items);
  public A removeMatchingFromFromHeaders(Predicate<JWTHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFromHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<JWTHeader> getFromHeaders();
  public List<JWTHeader> buildFromHeaders();
  public JWTHeader buildFromHeader(int index);
  public JWTHeader buildFirstFromHeader();
  public JWTHeader buildLastFromHeader();
  public JWTHeader buildMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public Boolean hasMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public A withFromHeaders(List<JWTHeader> fromHeaders);
  public A withFromHeaders(io.fabric8.istio.api.security.v1beta1.JWTHeader... fromHeaders);
  public Boolean hasFromHeaders();
  public A addNewFromHeader(String name,String prefix);
  public JWTRuleFluent.FromHeadersNested<A> addNewFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> addNewFromHeaderLike(JWTHeader item);
  public JWTRuleFluent.FromHeadersNested<A> setNewFromHeaderLike(int index,JWTHeader item);
  public JWTRuleFluent.FromHeadersNested<A> editFromHeader(int index);
  public JWTRuleFluent.FromHeadersNested<A> editFirstFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> editLastFromHeader();
  public JWTRuleFluent.FromHeadersNested<A> editMatchingFromHeader(Predicate<JWTHeaderBuilder> predicate);
  public A addToFromParams(int index,String item);
  public A setToFromParams(int index,String item);
  public A addToFromParams(java.lang.String... items);
  public A addAllToFromParams(Collection<String> items);
  public A removeFromFromParams(java.lang.String... items);
  public A removeAllFromFromParams(Collection<String> items);
  public List<String> getFromParams();
  public String getFromParam(int index);
  public String getFirstFromParam();
  public String getLastFromParam();
  public String getMatchingFromParam(Predicate<String> predicate);
  public Boolean hasMatchingFromParam(Predicate<String> predicate);
  public A withFromParams(List<String> fromParams);
  public A withFromParams(java.lang.String... fromParams);
  public Boolean hasFromParams();
  public String getIssuer();
  public A withIssuer(String issuer);
  public Boolean hasIssuer();
  public String getJwks();
  public A withJwks(String jwks);
  public Boolean hasJwks();
  public String getJwksUri();
  public A withJwksUri(String jwksUri);
  public Boolean hasJwksUri();
  public String getOutputPayloadToHeader();
  public A withOutputPayloadToHeader(String outputPayloadToHeader);
  public Boolean hasOutputPayloadToHeader();
  public A withForwardOriginalToken();
  public interface FromHeadersNested<N> extends Nested<N>,JWTHeaderFluent<JWTRuleFluent.FromHeadersNested<N>>{
    public N and();
    public N endFromHeader();
    
  }
  
}
